@@ -69,8 +69,8 @@ def main():
     if 'Batch' in luc_data.index:
         luc_data = remove_batch_effect(luc_data)
     if args.output.endswith('tsv'):
-        luc_data.to_csv(args.output, sep='\t', index=False)
+        luc_data.transpose().to_csv(args.output, sep='\t', index=False)
     elif args.output.endsiwth('csv'):
-        luc_data.to_csv(args.output, index=False)
+        luc_data.transpose().to_csv(args.output, index=False)
     else:
         raise RuntimeError('Output should be a CSV or TSV file')
